ardt.datasets.AERTrialFilter
============================

.. currentmodule:: ardt.datasets

.. autoclass:: AERTrialFilter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AERTrialFilter.__init__
      ~AERTrialFilter.filter
   
   

   
   
   